# FPGA Tools

## Installing Vitis/Vivado

The first step is to install [Vitis/Vivado](https://www.xilinx.com/support/download.html) on your host machine's file system.

Currently, we are using version [2024.2](https://www.xilinx.com/support/download/index.html/content/xilinx/en/downloadNav/vivado-design-tools/2024-2.html).

## Content of the Dockerfile

Given that support is limited to a few Linux distributions, the docker is based on the file system of version 22.04 of the Ubuntu distribution.

The first step is to copy the installLibs.sh script to your new folder.

```sh
$ cd ~/<your_docker_folder>/
$ cp /tools/Xilinx/Vitis/2024.2/scripts/installLibs.sh ./
```

The second step is to create the Dockerfile and fill it in.

```sh
$ touch Dockerfile
$ <your_text_editor> Dockerfile
```

Please note, you have to modifiy `XILINXD_LICENSE_FILE` and `LM_LICENSE_FILE` environment variables.

Dockerfile content:

```lang-sh
# Use Ubuntu 22.04 as the base image
FROM ubuntu:22.04

# Set environment variables to ensure non-interactive installs
ENV DEBIAN_FRONTEND=noninteractive

# Update package lists and install necessary packages
RUN apt-get update && apt-get install -y \
    wget \
    curl \
    unzip \
    build-essential \
    locales \
    usbutils \
    vim \
    emacs \
    libudev1 \
    libudev-dev \
    && rm -rf /var/lib/apt/lists/*

# Generate the en_US.UTF-8 locale
RUN locale-gen en_US.UTF-8

# Set the locale environment variables
ENV LANG=en_US.UTF-8 \
    LC_ALL=en_US.UTF-8 \
    LANGUAGE=en_US.UTF-8

# Set LD_PRELOAD to automatically load the required libudev.so.1
ENV LD_PRELOAD=/lib/x86_64-linux-gnu/libudev.so.1

# Create the required directory (if needed) and copy your script or other necessary files
# Assuming the installLibs.sh script is available in the build context
COPY ./installLibs.sh /installLibs.sh

# Make sure the script is executable
RUN chmod +x /installLibs.sh

# Run the installation script during the build process
RUN /installLibs.sh

ENV XILINXD_LICENSE_FILE="2100@10.136.142.218"
ENV LM_LICENSE_FILE="2100@10.136.142.218"

# Make the script run automatically when the container starts
ENTRYPOINT ["/bin/bash", "-c", "source /tools/Xilinx/Vivado/2024.2/settings64.sh && exec bash"]
```

## Building the Docker image

```sh
$ docker build -t my-ubuntu-vitis-image .
```

## Allow Docker to access X11 server

The next command adds hostnames or user names to the list allowed to make connection to the X server.

```sh
$ xhost +local:docker
```

## Docker run command

1. `--privileged`: Grant the container additional privileges to access USB devices
2. `--device=/dev/ttyUSBX`: Expose USB device(s), adjust device name as needed
3. `--mount`: Mount folder
4. `-e DISPLAY=$DISPLAY`: Pass the `DISPLAY` variable to the container
5. `-v /tmp/.X11-unix:/tmp/.X11-unix`: Share the X11 socket with the container

```sh
$ docker run -it \
    --privileged \
    --device=/dev/ttyUSB0 \
    --device=/dev/ttyUSB3 \
    --device=/dev/usb* \
    --mount type=bind,source=/tools,target=/tools \
    --mount type=bind,source=/home/<your_user_name>,target=/home/<your_user_name> \
    -e DISPLAY=$DISPLAY \
    -v /tmp/.X11-unix:/tmp/.X11-unix \
    my-ubuntu-vitis-image
```

## Running Vivado

```sh
$ vivado
```

# Useful links

## A collection of `.gitignore` files

The following github repository contains a collection of `.gitignore` files useful for various projets.

[.gitignore file collection](https://github.com/github/gitignore)
